@@ -36,7 +36,7 @@ type <- sc.results$fmeta # Filtered metadata
 
 ## ----deno, echo=TRUE, eval=TRUE------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
 spectra <- transfIntensity(spectra, fun = sqrt)
-spectra <- wavSmoothing(spectra, thresh.scale = thScale)
+spectra <- wavSmoothing(spectra, method = "Wavelet", thresh.scale = thScale)
 spectra <- removeBaseline(spectra, method = "SNIP", iterations = ite)
 spectra <- calibrateIntensity(spectra, method = "PQN")
 
